@@ -5,7 +5,7 @@ import hashlib
 import logging
 import six
 import secrets
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, TypedDict
 from operator import itemgetter
 
 import sqlalchemy as sa
@@ -25,11 +25,19 @@ log = logging.getLogger(__name__)
 DrupalId = int
 UserDict = Dict[str, Any]
 
+class DetailsData(TypedDict):
+    name: str
+    email: str
+    id: DrupalId
+
 
 class Details:
     _props = ("name", "email", "id")
+    name: str
+    email: str
+    id: DrupalId
 
-    def __init__(self, data):
+    def __init__(self, data: DetailsData):
         self.name, self.email, self.id = itemgetter(*self._props)(data)
 
     def __iter__(self):
@@ -183,11 +191,11 @@ def _attach_details(id: str, details: Details) -> UserDict:
     Raises:
     ValidationError if email or username is not unique
     """
-    user = details.make_userdict()
-    user["id"] = id
-
     admin = tk.get_action("get_site_user")({"ignore_auth": True}, {})
-    user = tk.get_action("user_patch")({"user": admin["name"]}, user)
+    user = tk.get_action("user_show")({"user": admin["name"]}, {"id": id})
+    user.update(details.make_userdict())
+    # user_patch is not available in v2.9
+    user = tk.get_action("user_update")({"user": admin["name"]}, user)
     return user
 
 
